==> octave-2.9.14.tar.gz: octave-2.9.14/liboctave/sparse-sort.cc <==
/*

Copyright (C) 2004 David Bateman
Copyright (C) 1998-2004 Andy Adler

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <cassert>

#include "oct-sort.cc"
#include "quit.h"

#include "sparse-sort.h"

// A simple class and instantiation of the octave merge sort class
// to sort sparse data before matrix creation. This is significantly
// faster than using octave_qsort.

bool
octave_sparse_sidxl_comp (octave_sparse_sort_idxl* i, 
			  octave_sparse_sort_idxl* j)
{
  octave_idx_type tmp = i->c - j->c;
  if (tmp < 0)
    return true;
  else if (tmp > 0)
    return false;
  return  (i->r < j->r);
}

// Instantiate the sparse sorting class
template class octave_sort<octave_sparse_sort_idxl *>;

// Need to know the original order of the sorted indexes in
// sparse assignments, and this class does that
bool
octave_idx_vector_comp (octave_idx_vector_sort* i,
			octave_idx_vector_sort* j)
{
  return (i->i < j->i);
}

// Instantiate the sparse index sorting class
template class octave_sort<octave_idx_vector_sort *>;

// Instantiate the sorting class of octave_idx_type, need in MUL macro
template class octave_sort<octave_idx_type>;

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave-2.9.15.tar.gz: octave-2.9.15/liboctave/sparse-sort.cc <==
/*

Copyright (C) 2004, 2005, 2006, 2007 David Bateman
Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Andy Adler

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <cassert>

#include "oct-sort.cc"
#include "quit.h"

#include "sparse-sort.h"

// A simple class and instantiation of the octave merge sort class
// to sort sparse data before matrix creation. This is significantly
// faster than using octave_qsort.

bool
octave_sparse_sidxl_comp (octave_sparse_sort_idxl* i, 
			  octave_sparse_sort_idxl* j)
{
  octave_idx_type tmp = i->c - j->c;
  if (tmp < 0)
    return true;
  else if (tmp > 0)
    return false;
  return  (i->r < j->r);
}

// Instantiate the sparse sorting class
template class octave_sort<octave_sparse_sort_idxl *>;

// Need to know the original order of the sorted indexes in
// sparse assignments, and this class does that
bool
octave_idx_vector_comp (octave_idx_vector_sort* i,
			octave_idx_vector_sort* j)
{
  return (i->i < j->i);
}

// Instantiate the sparse index sorting class
template class octave_sort<octave_idx_vector_sort *>;

// Instantiate the sorting class of octave_idx_type, need in MUL macro
template class octave_sort<octave_idx_type>;

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/
